package com.ruoyi.system.mapper;

import java.time.LocalDate;
import java.util.List;
import com.ruoyi.system.domain.DailyScenic;
import com.ruoyi.system.domain.dto.MRTimeDto;
import org.apache.ibatis.annotations.Param;

/**
 * 各景区的每天统计数据Mapper接口
 * 
 * @author haotian
 * @date 2024-12-09
 */
public interface DailyScenicMapper 
{
    /**
     * 查询各景区的每天统计数据
     * 
     * @param dailyScenicId 各景区的每天统计数据主键
     * @return 各景区的每天统计数据
     */
    public DailyScenic selectDailyScenicByDailyScenicId(Long dailyScenicId);

    /**
     * 查询各景区的每天统计数据列表
     * 
     * @param dailyScenic 各景区的每天统计数据
     * @return 各景区的每天统计数据集合
     */
    public List<DailyScenic> selectDailyScenicList(DailyScenic dailyScenic);

    /**
     * 新增各景区的每天统计数据
     * 
     * @param dailyScenic 各景区的每天统计数据
     * @return 结果
     */
    public int insertDailyScenic(DailyScenic dailyScenic);

    /**
     * 修改各景区的每天统计数据
     * 
     * @param dailyScenic 各景区的每天统计数据
     * @return 结果
     */
    public int updateDailyScenic(DailyScenic dailyScenic);

    /**
     * 删除各景区的每天统计数据
     * 
     * @param dailyScenicId 各景区的每天统计数据主键
     * @return 结果
     */
    public int deleteDailyScenicByDailyScenicId(Long dailyScenicId);

    /**
     * 批量删除各景区的每天统计数据
     * 
     * @param dailyScenicIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDailyScenicByDailyScenicIds(Long[] dailyScenicIds);


    public List<MRTimeDto> getMRTime(@Param("scenicId") Long scenicId,@Param("startDate") LocalDate startDate,@Param("endDate") LocalDate endDate);
}
