//package com.ruoyi.system.controller;
//
//import java.util.List;
//import javax.servlet.http.HttpServletResponse;
//import org.springframework.security.access.prepost.PreAuthorize;
//import org.springframework.beans.factory.annotation.Autowired;
//import org.springframework.web.bind.annotation.GetMapping;
//import org.springframework.web.bind.annotation.PostMapping;
//import org.springframework.web.bind.annotation.PutMapping;
//import org.springframework.web.bind.annotation.DeleteMapping;
//import org.springframework.web.bind.annotation.PathVariable;
//import org.springframework.web.bind.annotation.RequestBody;
//import org.springframework.web.bind.annotation.RequestMapping;
//import org.springframework.web.bind.annotation.RestController;
//import com.ruoyi.common.annotation.Log;
//import com.ruoyi.common.core.controller.BaseController;
//import com.ruoyi.common.core.domain.AjaxResult;
//import com.ruoyi.common.enums.BusinessType;
//import com.ruoyi.system.domain.DailyScenic;
//import com.ruoyi.system.service.IDailyScenicService;
//import com.ruoyi.common.utils.poi.ExcelUtil;
//import com.ruoyi.common.core.page.TableDataInfo;
//
///**
// * 各景区的每天统计数据Controller
// *
// * @author haotian
// * @date 2024-12-09
// */
//@RestController
//@RequestMapping("/system/scenic")
//public class DailyScenicController extends BaseController
//{
//    @Autowired
//    private IDailyScenicService dailyScenicService;
//
//    /**
//     * 查询各景区的每天统计数据列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:scenic:list')")
//    @GetMapping("/list")
//    public TableDataInfo list(DailyScenic dailyScenic)
//    {
//        startPage();
//        List<DailyScenic> list = dailyScenicService.selectDailyScenicList(dailyScenic);
//        return getDataTable(list);
//    }
//
//    /**
//     * 导出各景区的每天统计数据列表
//     */
//    @PreAuthorize("@ss.hasPermi('system:scenic:export')")
//    @Log(title = "各景区的每天统计数据", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, DailyScenic dailyScenic)
//    {
//        List<DailyScenic> list = dailyScenicService.selectDailyScenicList(dailyScenic);
//        ExcelUtil<DailyScenic> util = new ExcelUtil<DailyScenic>(DailyScenic.class);
//        util.exportExcel(response, list, "各景区的每天统计数据数据");
//    }
//
//    /**
//     * 获取各景区的每天统计数据详细信息
//     */
//    @PreAuthorize("@ss.hasPermi('system:scenic:query')")
//    @GetMapping(value = "/{dailyScenicId}")
//    public AjaxResult getInfo(@PathVariable("dailyScenicId") Long dailyScenicId)
//    {
//        return success(dailyScenicService.selectDailyScenicByDailyScenicId(dailyScenicId));
//    }
//
//    /**
//     * 新增各景区的每天统计数据
//     */
//    @PreAuthorize("@ss.hasPermi('system:scenic:add')")
//    @Log(title = "各景区的每天统计数据", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody DailyScenic dailyScenic)
//    {
//        return toAjax(dailyScenicService.insertDailyScenic(dailyScenic));
//    }
//
//    /**
//     * 修改各景区的每天统计数据
//     */
//    @PreAuthorize("@ss.hasPermi('system:scenic:edit')")
//    @Log(title = "各景区的每天统计数据", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody DailyScenic dailyScenic)
//    {
//        return toAjax(dailyScenicService.updateDailyScenic(dailyScenic));
//    }
//
//    /**
//     * 删除各景区的每天统计数据
//     */
//    @PreAuthorize("@ss.hasPermi('system:scenic:remove')")
//    @Log(title = "各景区的每天统计数据", businessType = BusinessType.DELETE)
//	@DeleteMapping("/{dailyScenicIds}")
//    public AjaxResult remove(@PathVariable Long[] dailyScenicIds)
//    {
//        return toAjax(dailyScenicService.deleteDailyScenicByDailyScenicIds(dailyScenicIds));
//    }
//}
